# vim: set sw=4 ts=4 et:
# Copyright (c) 2008-2010 oc2pus
# This file and all modifications and additions to the pristine
# package are under the same license as the package itself.
#
# Please submit bugfixes or comments to packman@links2linux.de

%define soname	0

Name:           libzen
Version:        0.4.28
Release:        1.1
Summary:        Shared library for mediainfo
Group:          System/Libraries
License:        BSD-3-Clause
URL:            http://zenlib.sourceforge.net/
Source:         http://prdownloads.sourceforge.net/zenlib/libzen_%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires:  autoconf 
BuildRequires:  automake 
BuildRequires:  fdupes
BuildRequires:  libtool
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig

%description
Shared library for libmediainfo and medianfo-gui.

%package -n %{name}%{soname}
Summary:        Shared library for mediainfo
Group:          System/Libraries

%description -n %{name}%{soname}
Shared library for libmediainfo and medianfo-gui.

%package -n libzen-devel
Summary:        Include files and libraries for development
Group:          Development/Libraries/C and C++
Requires:       %{name}%{soname} = %{version}

%description -n libzen-devel
Include files and mandatory libraries for development.

%prep
%setup -q -n ZenLib
%__sed -i 's/\r$//' *.txt Source/Doc/*.html
%__chmod 644 *.txt Source/Doc/*.html

%build
# generate docs
pushd Source/Doc
    doxygen -u 2> /dev/null
    doxygen Doxyfile
popd

export CFLAGS="$RPM_OPT_FLAGS"
export CPPFLAGS="$RPM_OPT_FLAGS"
export CXXFLAGS="$RPM_OPT_FLAGS"

pushd Project/GNU/Library
    %__chmod +x autogen
    NOCONFIGURE=1 ./autogen
    %configure \
    	--enable-shared

    %__make clean
    %__make %{?_smp_flags}
popd

%install
pushd Project/GNU/Library
    %makeinstall
popd

# Zenlib headers and ZenLib-config
%__install -dm 755 %{buildroot}%{_includedir}/ZenLib
%__install -m 644 Source/ZenLib/*.h \
    %{buildroot}%{_includedir}/ZenLib
for i in HTTP_Client Format/Html Format/Http; do
    %__install -dm 755 %{buildroot}%{_includedir}/ZenLib/$i
    %__install -m 644 Source/ZenLib/$i/*.h \
    	%{buildroot}%{_includedir}/ZenLib/$i
done

%__sed -i -e 's|Version: |Version: %{version}|g' \
    Project/GNU/Library/libzen.pc
%__install -dm 755 %{buildroot}%{_libdir}/pkgconfig
%__install -m 644 Project/GNU/Library/libzen.pc \
    %{buildroot}%{_libdir}/pkgconfig

%__rm %{buildroot}%{_libdir}/libzen.a
%__rm %{buildroot}%{_libdir}/libzen.la

# we don't need libzen-config
rm %{buildroot}%{_bindir}/libzen-config

%fdupes %{buildroot}

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%post   -n %{name}%{soname} -p /sbin/ldconfig
%postun -n %{name}%{soname} -p /sbin/ldconfig

%files -n %{name}%{soname}
%defattr(-,root,root,-)
%doc *.txt
%{_libdir}/libzen.so.%{soname}
%{_libdir}/libzen.so.%{soname}.*

%files -n libzen-devel
%defattr(-,root,root,-)
%doc Source/Doc/Documentation.html
%doc Doc/*
%dir %{_includedir}/ZenLib
%{_includedir}/ZenLib/*
%{_libdir}/libzen.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Thu Oct  4 2012 i@marguerite.su  
- Update to 0.4.28
  * Removing _T() in order to be compatible with LLVM compiler
  * Ztring: UTF-16 conversion routines crash if the provided string size is odd.
  * GNU: forcing stdc++ at link
* Sat May 19 2012 seife+obs@b1-systems.com
- add autoconf/automake/libtool to buildrequires to fix 12.2 build
* Tue Oct 18 2011 nomail@nomail.com
- Update to 0.4.22
  x #3412495, Ztring: To_UTF8() was working wrong, corrected
    thanks to Andrew Jang
  x #3157308, Ztring::Assign_FromFile(): Memory leak
  + TinyXml updated
  + float16 (on disk) support
  + Ztring: more compatibility with uCLibC
  x BitStream_LE: wrong result if buffer underrun
  + HTTP helpers in Unicode version
  x BitStream Little Endian: count of remaining bits was wrong
  x ZtringList and ZtringListList :: Read(): do not remove pending
    delimiters
  x File Open status: error with Windows return value
* Tue Mar  8 2011 pascal.bleser@opensuse.org
- add baselibs.conf
- update to 0.4.17:
  * BitStream: skip methods improvements
- changes from 0.4.16:
  * BitStream: Peek3()
  * decimal point issues with some specific compilers/OS
  * ZtringList: issues with EOL
  * #3025205, file is not opened if a "?" is in it
* Sat Jul 31 2010 toni@links2linux.de
- update to 0.4.15
* Mon May  3 2010 toni@links2linux.de
- update to 0.4.14
* Fri Apr 16 2010 toni@links2linux.de
- update to 0.4.13
* Tue Mar  9 2010 toni@links2linux.de
- update to 0.4.12
* Sun Feb 21 2010 toni@links2linux.de
- update to 0.4.11
* Mon Jan 11 2010 toni@links2linux.de
- update to 0.4.10
* Fri Nov 20 2009 toni@links2linux.de
- update to 0.4.9
* Fri Oct 30 2009 toni@links2linux.de
- update to 0.4.8
* Tue Oct 27 2009 toni@links2linux.de
- update to 0.4.7
* Tue Oct 13 2009 toni@links2linux.de
- update to 0.4.6
* Fri Apr 17 2009 toni@links2linux.de
- update to 0.4.2
* Sun Apr  5 2009 toni@links2linux.de
- update to 0.4.1
* Sat Apr  4 2009 toni@links2linux.de
- redowngrade to 0.4.0
* Thu Apr  2 2009 toni@links2linux.de
- update to 0.4.1
* Fri Mar 20 2009 toni@links2linux.de
- update to 0.4.0
* Fri Feb 13 2009 toni@links2linux.de
- update to 0.3.8
* Fri Jan 30 2009 toni@links2linux.de
- update to 0.3.7
* Fri Jan 23 2009 toni@links2linux.de
- update to 0.3.6
* Tue Dec  9 2008 toni@links2linux.de
- update to 0.3.5
- docs are now generated with doxygen
* Mon Nov 17 2008 toni@links2linux.de
- added api-doc to devel subpackage
- instead of ZenLib-config now a pkgconfig file is provided
* Mon Dec 10 2007 toni@links2linux.de
- libZenLib and libMediaInfoLib are renamed to libzen and libmediainfo
- install *-config files manually
- added devel-subpackages
- split off from MediaInfo package
